using System;
using FitConnect;
using FitConnect.Models;
using FluentAssertions;
using NUnit.Framework;

namespace IntegrationTests.Sender;

[TestFixture]
public class SenderTestUnhappyPath : SenderTestBase {
    [Test]
    public void WithDestination_CompletelyWrong_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => {
                SubmissionBuilder.WithDestination("This is very wrong");
            })!
            .Message.Should().Be("The destination must be a valid GUID");
    }

    [Test]
    public void WithData_DataIsInvalidJson_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => {
                SubmissionBuilder.WithDestination(DestinationId)
                    .WithServiceType("Name", "urn:de:fim:leika:leistung:00000000000000")
                    .WithJsonData("This is very wrong")
                    .WithAttachments(new Attachment("Test.pdf", "Test PDF"));
            })!
            .Message.Should().Be("The data must be valid JSON string");
    }
}
